@@ -1,5 +1,8 @@
 #!/usr/bin/env python3
 # coding: utf-8
-__version__ = '0.2.4'
 
 from joker.environ.generic import GlobalInterface
+from joker.interfaces import __version__
+
+if __name__ == '__main__':
+    print(__version__)
